# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Doc(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Doc - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'document_type': 'str',
            'document_content': 'str',
            'document_url': 'str',
            'test': 'bool',
            'strict': 'str',
            'ignore_resource_errors': 'bool',
            'tag': 'str',
            'help': 'bool',
            'javascript': 'bool',
            'referrer': 'str',
            'callback_url': 'str',
            'prince_options': 'PrinceOptions'
        }

        self.attribute_map = {
            'name': 'name',
            'document_type': 'document_type',
            'document_content': 'document_content',
            'document_url': 'document_url',
            'test': 'test',
            'strict': 'strict',
            'ignore_resource_errors': 'ignore_resource_errors',
            'tag': 'tag',
            'help': 'help',
            'javascript': 'javascript',
            'referrer': 'referrer',
            'callback_url': 'callback_url',
            'prince_options': 'prince_options'
        }

        self._name = None
        self._document_type = None
        self._document_content = None
        self._document_url = None
        self._test = True
        self._strict = 'none'
        self._ignore_resource_errors = True
        self._tag = None
        self._help = False
        self._javascript = False
        self._referrer = None
        self._callback_url = None
        self._prince_options = None

    @property
    def name(self):
        """
        Gets the name of this Doc.
        A name for identifying your document.

        :return: The name of this Doc.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Doc.
        A name for identifying your document.

        :param name: The name of this Doc.
        :type: str
        """
        self._name = name

    @property
    def document_type(self):
        """
        Gets the document_type of this Doc.
        The type of document being created.

        :return: The document_type of this Doc.
        :rtype: str
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """
        Sets the document_type of this Doc.
        The type of document being created.

        :param document_type: The document_type of this Doc.
        :type: str
        """
        allowed_values = ["pdf", "xls", "xlsx"]
        if document_type not in allowed_values:
            raise ValueError(
                "Invalid value for `document_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._document_type = document_type

    @property
    def document_content(self):
        """
        Gets the document_content of this Doc.
        The HTML data to be transformed into a document. You must supply content using document_content or document_url.

        :return: The document_content of this Doc.
        :rtype: str
        """
        return self._document_content

    @document_content.setter
    def document_content(self, document_content):
        """
        Sets the document_content of this Doc.
        The HTML data to be transformed into a document. You must supply content using document_content or document_url.

        :param document_content: The document_content of this Doc.
        :type: str
        """
        self._document_content = document_content

    @property
    def document_url(self):
        """
        Gets the document_url of this Doc.
        The URL to fetch the HTML data to be transformed into a document. You must supply content using document_content or document_url.

        :return: The document_url of this Doc.
        :rtype: str
        """
        return self._document_url

    @document_url.setter
    def document_url(self, document_url):
        """
        Sets the document_url of this Doc.
        The URL to fetch the HTML data to be transformed into a document. You must supply content using document_content or document_url.

        :param document_url: The document_url of this Doc.
        :type: str
        """
        self._document_url = document_url

    @property
    def test(self):
        """
        Gets the test of this Doc.
        Enable test mode for this document. Test documents are not charged for but include a watermark.

        :return: The test of this Doc.
        :rtype: bool
        """
        return self._test

    @test.setter
    def test(self, test):
        """
        Sets the test of this Doc.
        Enable test mode for this document. Test documents are not charged for but include a watermark.

        :param test: The test of this Doc.
        :type: bool
        """
        self._test = test

    @property
    def strict(self):
        """
        Gets the strict of this Doc.
        Force strict HTML validation.

        :return: The strict of this Doc.
        :rtype: str
        """
        return self._strict

    @strict.setter
    def strict(self, strict):
        """
        Sets the strict of this Doc.
        Force strict HTML validation.

        :param strict: The strict of this Doc.
        :type: str
        """
        allowed_values = ["none"]
        if strict not in allowed_values:
            raise ValueError(
                "Invalid value for `strict`, must be one of {0}"
                .format(allowed_values)
            )
        self._strict = strict

    @property
    def ignore_resource_errors(self):
        """
        Gets the ignore_resource_errors of this Doc.
        Failed loading of images/javascripts/stylesheets/etc. will not cause the rendering to stop.

        :return: The ignore_resource_errors of this Doc.
        :rtype: bool
        """
        return self._ignore_resource_errors

    @ignore_resource_errors.setter
    def ignore_resource_errors(self, ignore_resource_errors):
        """
        Sets the ignore_resource_errors of this Doc.
        Failed loading of images/javascripts/stylesheets/etc. will not cause the rendering to stop.

        :param ignore_resource_errors: The ignore_resource_errors of this Doc.
        :type: bool
        """
        self._ignore_resource_errors = ignore_resource_errors

    @property
    def tag(self):
        """
        Gets the tag of this Doc.
        A field for storing a small amount of metadata with this document.

        :return: The tag of this Doc.
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """
        Sets the tag of this Doc.
        A field for storing a small amount of metadata with this document.

        :param tag: The tag of this Doc.
        :type: str
        """
        self._tag = tag

    @property
    def help(self):
        """
        Gets the help of this Doc.
        Request support help with this request if it succeeds.

        :return: The help of this Doc.
        :rtype: bool
        """
        return self._help

    @help.setter
    def help(self, help):
        """
        Sets the help of this Doc.
        Request support help with this request if it succeeds.

        :param help: The help of this Doc.
        :type: bool
        """
        self._help = help

    @property
    def javascript(self):
        """
        Gets the javascript of this Doc.
        Enable DocRaptor JavaScript parsing. PrinceXML JavaScript parsing is also available elsewhere.

        :return: The javascript of this Doc.
        :rtype: bool
        """
        return self._javascript

    @javascript.setter
    def javascript(self, javascript):
        """
        Sets the javascript of this Doc.
        Enable DocRaptor JavaScript parsing. PrinceXML JavaScript parsing is also available elsewhere.

        :param javascript: The javascript of this Doc.
        :type: bool
        """
        self._javascript = javascript

    @property
    def referrer(self):
        """
        Gets the referrer of this Doc.
        Set HTTP referrer when generating this document.

        :return: The referrer of this Doc.
        :rtype: str
        """
        return self._referrer

    @referrer.setter
    def referrer(self, referrer):
        """
        Sets the referrer of this Doc.
        Set HTTP referrer when generating this document.

        :param referrer: The referrer of this Doc.
        :type: str
        """
        self._referrer = referrer

    @property
    def callback_url(self):
        """
        Gets the callback_url of this Doc.
        A URL that will receive a POST request after successfully completing an asynchronous document. The POST data will include download_url and download_id similar to status api responses. WARNING: this only works on asynchronous documents.

        :return: The callback_url of this Doc.
        :rtype: str
        """
        return self._callback_url

    @callback_url.setter
    def callback_url(self, callback_url):
        """
        Sets the callback_url of this Doc.
        A URL that will receive a POST request after successfully completing an asynchronous document. The POST data will include download_url and download_id similar to status api responses. WARNING: this only works on asynchronous documents.

        :param callback_url: The callback_url of this Doc.
        :type: str
        """
        self._callback_url = callback_url

    @property
    def prince_options(self):
        """
        Gets the prince_options of this Doc.


        :return: The prince_options of this Doc.
        :rtype: PrinceOptions
        """
        return self._prince_options

    @prince_options.setter
    def prince_options(self, prince_options):
        """
        Sets the prince_options of this Doc.


        :param prince_options: The prince_options of this Doc.
        :type: PrinceOptions
        """
        self._prince_options = prince_options

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class PrinceOptions(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PrinceOptions - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'baseurl': 'str',
            'no_xinclude': 'bool',
            'no_network': 'bool',
            'http_user': 'str',
            'http_password': 'str',
            'http_proxy': 'str',
            'http_timeout': 'int',
            'insecure': 'bool',
            'media': 'str',
            'no_author_style': 'bool',
            'no_default_style': 'bool',
            'no_embed_fonts': 'bool',
            'no_subset_fonts': 'bool',
            'no_compress': 'bool',
            'encrypt': 'bool',
            'key_bits': 'int',
            'user_password': 'str',
            'owner_password': 'str',
            'disallow_print': 'bool',
            'disallow_copy': 'bool',
            'disallow_annotate': 'bool',
            'disallow_modify': 'bool',
            'debug': 'bool',
            'input': 'str',
            'version': 'str',
            'javascript': 'bool',
            'css_dpi': 'int',
            'profile': 'str'
        }

        self.attribute_map = {
            'baseurl': 'baseurl',
            'no_xinclude': 'no_xinclude',
            'no_network': 'no_network',
            'http_user': 'http_user',
            'http_password': 'http_password',
            'http_proxy': 'http_proxy',
            'http_timeout': 'http_timeout',
            'insecure': 'insecure',
            'media': 'media',
            'no_author_style': 'no_author_style',
            'no_default_style': 'no_default_style',
            'no_embed_fonts': 'no_embed_fonts',
            'no_subset_fonts': 'no_subset_fonts',
            'no_compress': 'no_compress',
            'encrypt': 'encrypt',
            'key_bits': 'key_bits',
            'user_password': 'user_password',
            'owner_password': 'owner_password',
            'disallow_print': 'disallow_print',
            'disallow_copy': 'disallow_copy',
            'disallow_annotate': 'disallow_annotate',
            'disallow_modify': 'disallow_modify',
            'debug': 'debug',
            'input': 'input',
            'version': 'version',
            'javascript': 'javascript',
            'css_dpi': 'css_dpi',
            'profile': 'profile'
        }

        self._baseurl = None
        self._no_xinclude = None
        self._no_network = None
        self._http_user = None
        self._http_password = None
        self._http_proxy = None
        self._http_timeout = None
        self._insecure = None
        self._media = 'print'
        self._no_author_style = None
        self._no_default_style = None
        self._no_embed_fonts = None
        self._no_subset_fonts = None
        self._no_compress = None
        self._encrypt = None
        self._key_bits = None
        self._user_password = None
        self._owner_password = None
        self._disallow_print = None
        self._disallow_copy = None
        self._disallow_annotate = None
        self._disallow_modify = None
        self._debug = None
        self._input = 'html'
        self._version = None
        self._javascript = None
        self._css_dpi = None
        self._profile = None

    @property
    def baseurl(self):
        """
        Gets the baseurl of this PrinceOptions.
        Set the baseurl for assets.

        :return: The baseurl of this PrinceOptions.
        :rtype: str
        """
        return self._baseurl

    @baseurl.setter
    def baseurl(self, baseurl):
        """
        Sets the baseurl of this PrinceOptions.
        Set the baseurl for assets.

        :param baseurl: The baseurl of this PrinceOptions.
        :type: str
        """
        self._baseurl = baseurl

    @property
    def no_xinclude(self):
        """
        Gets the no_xinclude of this PrinceOptions.
        Disable XML inclusion.

        :return: The no_xinclude of this PrinceOptions.
        :rtype: bool
        """
        return self._no_xinclude

    @no_xinclude.setter
    def no_xinclude(self, no_xinclude):
        """
        Sets the no_xinclude of this PrinceOptions.
        Disable XML inclusion.

        :param no_xinclude: The no_xinclude of this PrinceOptions.
        :type: bool
        """
        self._no_xinclude = no_xinclude

    @property
    def no_network(self):
        """
        Gets the no_network of this PrinceOptions.
        Disable network access.

        :return: The no_network of this PrinceOptions.
        :rtype: bool
        """
        return self._no_network

    @no_network.setter
    def no_network(self, no_network):
        """
        Sets the no_network of this PrinceOptions.
        Disable network access.

        :param no_network: The no_network of this PrinceOptions.
        :type: bool
        """
        self._no_network = no_network

    @property
    def http_user(self):
        """
        Gets the http_user of this PrinceOptions.
        Set the user for HTTP authentication.

        :return: The http_user of this PrinceOptions.
        :rtype: str
        """
        return self._http_user

    @http_user.setter
    def http_user(self, http_user):
        """
        Sets the http_user of this PrinceOptions.
        Set the user for HTTP authentication.

        :param http_user: The http_user of this PrinceOptions.
        :type: str
        """
        self._http_user = http_user

    @property
    def http_password(self):
        """
        Gets the http_password of this PrinceOptions.
        Set the password for HTTP authentication.

        :return: The http_password of this PrinceOptions.
        :rtype: str
        """
        return self._http_password

    @http_password.setter
    def http_password(self, http_password):
        """
        Sets the http_password of this PrinceOptions.
        Set the password for HTTP authentication.

        :param http_password: The http_password of this PrinceOptions.
        :type: str
        """
        self._http_password = http_password

    @property
    def http_proxy(self):
        """
        Gets the http_proxy of this PrinceOptions.
        Set the HTTP proxy server.

        :return: The http_proxy of this PrinceOptions.
        :rtype: str
        """
        return self._http_proxy

    @http_proxy.setter
    def http_proxy(self, http_proxy):
        """
        Sets the http_proxy of this PrinceOptions.
        Set the HTTP proxy server.

        :param http_proxy: The http_proxy of this PrinceOptions.
        :type: str
        """
        self._http_proxy = http_proxy

    @property
    def http_timeout(self):
        """
        Gets the http_timeout of this PrinceOptions.
        Set the HTTP request timeout.

        :return: The http_timeout of this PrinceOptions.
        :rtype: int
        """
        return self._http_timeout

    @http_timeout.setter
    def http_timeout(self, http_timeout):
        """
        Sets the http_timeout of this PrinceOptions.
        Set the HTTP request timeout.

        :param http_timeout: The http_timeout of this PrinceOptions.
        :type: int
        """
        self._http_timeout = http_timeout

    @property
    def insecure(self):
        """
        Gets the insecure of this PrinceOptions.
        Disable SSL verification.

        :return: The insecure of this PrinceOptions.
        :rtype: bool
        """
        return self._insecure

    @insecure.setter
    def insecure(self, insecure):
        """
        Sets the insecure of this PrinceOptions.
        Disable SSL verification.

        :param insecure: The insecure of this PrinceOptions.
        :type: bool
        """
        self._insecure = insecure

    @property
    def media(self):
        """
        Gets the media of this PrinceOptions.
        Specify the CSS media type. Defaults to \"print\" but you may want to use \"screen\" for web styles.

        :return: The media of this PrinceOptions.
        :rtype: str
        """
        return self._media

    @media.setter
    def media(self, media):
        """
        Sets the media of this PrinceOptions.
        Specify the CSS media type. Defaults to \"print\" but you may want to use \"screen\" for web styles.

        :param media: The media of this PrinceOptions.
        :type: str
        """
        self._media = media

    @property
    def no_author_style(self):
        """
        Gets the no_author_style of this PrinceOptions.
        Ignore author stylesheets.

        :return: The no_author_style of this PrinceOptions.
        :rtype: bool
        """
        return self._no_author_style

    @no_author_style.setter
    def no_author_style(self, no_author_style):
        """
        Sets the no_author_style of this PrinceOptions.
        Ignore author stylesheets.

        :param no_author_style: The no_author_style of this PrinceOptions.
        :type: bool
        """
        self._no_author_style = no_author_style

    @property
    def no_default_style(self):
        """
        Gets the no_default_style of this PrinceOptions.
        Ignore default stylesheets.

        :return: The no_default_style of this PrinceOptions.
        :rtype: bool
        """
        return self._no_default_style

    @no_default_style.setter
    def no_default_style(self, no_default_style):
        """
        Sets the no_default_style of this PrinceOptions.
        Ignore default stylesheets.

        :param no_default_style: The no_default_style of this PrinceOptions.
        :type: bool
        """
        self._no_default_style = no_default_style

    @property
    def no_embed_fonts(self):
        """
        Gets the no_embed_fonts of this PrinceOptions.
        Disable font embedding in PDFs.

        :return: The no_embed_fonts of this PrinceOptions.
        :rtype: bool
        """
        return self._no_embed_fonts

    @no_embed_fonts.setter
    def no_embed_fonts(self, no_embed_fonts):
        """
        Sets the no_embed_fonts of this PrinceOptions.
        Disable font embedding in PDFs.

        :param no_embed_fonts: The no_embed_fonts of this PrinceOptions.
        :type: bool
        """
        self._no_embed_fonts = no_embed_fonts

    @property
    def no_subset_fonts(self):
        """
        Gets the no_subset_fonts of this PrinceOptions.
        Disable font subsetting in PDFs.

        :return: The no_subset_fonts of this PrinceOptions.
        :rtype: bool
        """
        return self._no_subset_fonts

    @no_subset_fonts.setter
    def no_subset_fonts(self, no_subset_fonts):
        """
        Sets the no_subset_fonts of this PrinceOptions.
        Disable font subsetting in PDFs.

        :param no_subset_fonts: The no_subset_fonts of this PrinceOptions.
        :type: bool
        """
        self._no_subset_fonts = no_subset_fonts

    @property
    def no_compress(self):
        """
        Gets the no_compress of this PrinceOptions.
        Disable PDF compression.

        :return: The no_compress of this PrinceOptions.
        :rtype: bool
        """
        return self._no_compress

    @no_compress.setter
    def no_compress(self, no_compress):
        """
        Sets the no_compress of this PrinceOptions.
        Disable PDF compression.

        :param no_compress: The no_compress of this PrinceOptions.
        :type: bool
        """
        self._no_compress = no_compress

    @property
    def encrypt(self):
        """
        Gets the encrypt of this PrinceOptions.
        Encrypt PDF output.

        :return: The encrypt of this PrinceOptions.
        :rtype: bool
        """
        return self._encrypt

    @encrypt.setter
    def encrypt(self, encrypt):
        """
        Sets the encrypt of this PrinceOptions.
        Encrypt PDF output.

        :param encrypt: The encrypt of this PrinceOptions.
        :type: bool
        """
        self._encrypt = encrypt

    @property
    def key_bits(self):
        """
        Gets the key_bits of this PrinceOptions.
        Set encryption key size.

        :return: The key_bits of this PrinceOptions.
        :rtype: int
        """
        return self._key_bits

    @key_bits.setter
    def key_bits(self, key_bits):
        """
        Sets the key_bits of this PrinceOptions.
        Set encryption key size.

        :param key_bits: The key_bits of this PrinceOptions.
        :type: int
        """
        self._key_bits = key_bits

    @property
    def user_password(self):
        """
        Gets the user_password of this PrinceOptions.
        Set the PDF user password.

        :return: The user_password of this PrinceOptions.
        :rtype: str
        """
        return self._user_password

    @user_password.setter
    def user_password(self, user_password):
        """
        Sets the user_password of this PrinceOptions.
        Set the PDF user password.

        :param user_password: The user_password of this PrinceOptions.
        :type: str
        """
        self._user_password = user_password

    @property
    def owner_password(self):
        """
        Gets the owner_password of this PrinceOptions.
        Set the PDF owner password.

        :return: The owner_password of this PrinceOptions.
        :rtype: str
        """
        return self._owner_password

    @owner_password.setter
    def owner_password(self, owner_password):
        """
        Sets the owner_password of this PrinceOptions.
        Set the PDF owner password.

        :param owner_password: The owner_password of this PrinceOptions.
        :type: str
        """
        self._owner_password = owner_password

    @property
    def disallow_print(self):
        """
        Gets the disallow_print of this PrinceOptions.
        Disallow printing of this PDF.

        :return: The disallow_print of this PrinceOptions.
        :rtype: bool
        """
        return self._disallow_print

    @disallow_print.setter
    def disallow_print(self, disallow_print):
        """
        Sets the disallow_print of this PrinceOptions.
        Disallow printing of this PDF.

        :param disallow_print: The disallow_print of this PrinceOptions.
        :type: bool
        """
        self._disallow_print = disallow_print

    @property
    def disallow_copy(self):
        """
        Gets the disallow_copy of this PrinceOptions.
        Disallow copying of this PDF.

        :return: The disallow_copy of this PrinceOptions.
        :rtype: bool
        """
        return self._disallow_copy

    @disallow_copy.setter
    def disallow_copy(self, disallow_copy):
        """
        Sets the disallow_copy of this PrinceOptions.
        Disallow copying of this PDF.

        :param disallow_copy: The disallow_copy of this PrinceOptions.
        :type: bool
        """
        self._disallow_copy = disallow_copy

    @property
    def disallow_annotate(self):
        """
        Gets the disallow_annotate of this PrinceOptions.
        Disallow annotation of this PDF.

        :return: The disallow_annotate of this PrinceOptions.
        :rtype: bool
        """
        return self._disallow_annotate

    @disallow_annotate.setter
    def disallow_annotate(self, disallow_annotate):
        """
        Sets the disallow_annotate of this PrinceOptions.
        Disallow annotation of this PDF.

        :param disallow_annotate: The disallow_annotate of this PrinceOptions.
        :type: bool
        """
        self._disallow_annotate = disallow_annotate

    @property
    def disallow_modify(self):
        """
        Gets the disallow_modify of this PrinceOptions.
        Disallow modification of this PDF.

        :return: The disallow_modify of this PrinceOptions.
        :rtype: bool
        """
        return self._disallow_modify

    @disallow_modify.setter
    def disallow_modify(self, disallow_modify):
        """
        Sets the disallow_modify of this PrinceOptions.
        Disallow modification of this PDF.

        :param disallow_modify: The disallow_modify of this PrinceOptions.
        :type: bool
        """
        self._disallow_modify = disallow_modify

    @property
    def debug(self):
        """
        Gets the debug of this PrinceOptions.
        Enable Prince debug mode.

        :return: The debug of this PrinceOptions.
        :rtype: bool
        """
        return self._debug

    @debug.setter
    def debug(self, debug):
        """
        Sets the debug of this PrinceOptions.
        Enable Prince debug mode.

        :param debug: The debug of this PrinceOptions.
        :type: bool
        """
        self._debug = debug

    @property
    def input(self):
        """
        Gets the input of this PrinceOptions.
        Specify the input format.

        :return: The input of this PrinceOptions.
        :rtype: str
        """
        return self._input

    @input.setter
    def input(self, input):
        """
        Sets the input of this PrinceOptions.
        Specify the input format.

        :param input: The input of this PrinceOptions.
        :type: str
        """
        allowed_values = ["html", "xml", "auto"]
        if input not in allowed_values:
            raise ValueError(
                "Invalid value for `input`, must be one of {0}"
                .format(allowed_values)
            )
        self._input = input

    @property
    def version(self):
        """
        Gets the version of this PrinceOptions.
        Specify a specific verison of PrinceXML to use.

        :return: The version of this PrinceOptions.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this PrinceOptions.
        Specify a specific verison of PrinceXML to use.

        :param version: The version of this PrinceOptions.
        :type: str
        """
        self._version = version

    @property
    def javascript(self):
        """
        Gets the javascript of this PrinceOptions.
        Enable PrinceXML JavaScript. DocRaptor JavaScript parsing is also available elsewhere.

        :return: The javascript of this PrinceOptions.
        :rtype: bool
        """
        return self._javascript

    @javascript.setter
    def javascript(self, javascript):
        """
        Sets the javascript of this PrinceOptions.
        Enable PrinceXML JavaScript. DocRaptor JavaScript parsing is also available elsewhere.

        :param javascript: The javascript of this PrinceOptions.
        :type: bool
        """
        self._javascript = javascript

    @property
    def css_dpi(self):
        """
        Gets the css_dpi of this PrinceOptions.
        Set the DPI when rendering CSS. Defaults to 96 but can be set with Prince 9.0 and up.

        :return: The css_dpi of this PrinceOptions.
        :rtype: int
        """
        return self._css_dpi

    @css_dpi.setter
    def css_dpi(self, css_dpi):
        """
        Sets the css_dpi of this PrinceOptions.
        Set the DPI when rendering CSS. Defaults to 96 but can be set with Prince 9.0 and up.

        :param css_dpi: The css_dpi of this PrinceOptions.
        :type: int
        """
        self._css_dpi = css_dpi

    @property
    def profile(self):
        """
        Gets the profile of this PrinceOptions.
        In Prince 9.0 and up you can set the PDF profile.

        :return: The profile of this PrinceOptions.
        :rtype: str
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """
        Sets the profile of this PrinceOptions.
        In Prince 9.0 and up you can set the PDF profile.

        :param profile: The profile of this PrinceOptions.
        :type: str
        """
        self._profile = profile

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




from __future__ import absolute_import

# import models into model package
from .async_doc import AsyncDoc
from .async_doc_status import AsyncDocStatus
from .doc import Doc
from .prince_options import PrinceOptions



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

Credit: this file (rest.py) is modified based on rest.py in Dropbox Python SDK:
https://www.dropbox.com/developers/core/sdks/python
"""
from __future__ import absolute_import

import sys
import io
import json
import ssl
import certifi
import logging

# python 2 and python 3 compatibility library
from six import iteritems

from .configuration import Configuration

try:
    import urllib3
except ImportError:
    raise ImportError('Swagger python client requires urllib3.')

try:
    # for python3
    from urllib.parse import urlencode
except ImportError:
    # for python2
    from urllib import urlencode


logger = logging.getLogger(__name__)


class RESTResponse(io.IOBase):

    def __init__(self, resp):
        self.urllib3_response = resp
        self.status = resp.status
        self.reason = resp.reason
        self.data = resp.data

    def getheaders(self):
        """
        Returns a dictionary of the response headers.
        """
        return self.urllib3_response.getheaders()

    def getheader(self, name, default=None):
        """
        Returns a given response header.
        """
        return self.urllib3_response.getheader(name, default)


class RESTClientObject(object):

    def __init__(self, pools_size=4):
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680
        # ca_certs vs cert_file vs key_file
        # http://stackoverflow.com/a/23957365/2985775

        # cert_reqs
        if Configuration().verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        # ca_certs
        if Configuration().ssl_ca_cert:
            ca_certs = Configuration().ssl_ca_cert
        else:
            # if not set certificate file, use Mozilla's root certificates.
            ca_certs = certifi.where()

        # cert_file
        cert_file = Configuration().cert_file

        # key file
        key_file = Configuration().key_file

        # https pool manager
        self.pool_manager = urllib3.PoolManager(
            num_pools=pools_size,
            cert_reqs=cert_reqs,
            ca_certs=ca_certs,
            cert_file=cert_file,
            key_file=key_file
        )

    def request(self, method, url, query_params=None, headers=None,
                body=None, post_params=None):
        """
        :param method: http request method
        :param url: http request url
        :param query_params: query parameters in the url
        :param headers: http request headers
        :param body: request json body, for `application/json`
        :param post_params: request post parameters,
                            `application/x-www-form-urlencode`
                            and `multipart/form-data`
        """
        method = method.upper()
        assert method in ['GET', 'HEAD', 'DELETE', 'POST', 'PUT', 'PATCH', 'OPTIONS']

        if post_params and body:
            raise ValueError(
                "body parameter cannot be used with post_params parameter."
            )

        post_params = post_params or {}
        headers = headers or {}

        if 'Content-Type' not in headers:
            headers['Content-Type'] = 'application/json'

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`
            if method in ['POST', 'PUT', 'PATCH', 'OPTIONS']:
                if query_params:
                    url += '?' + urlencode(query_params)
                if headers['Content-Type'] == 'application/json':
                    r = self.pool_manager.request(method, url,
                                                  body=json.dumps(body),
                                                  headers=headers)
                if headers['Content-Type'] == 'application/x-www-form-urlencoded':
                    r = self.pool_manager.request(method, url,
                                                  fields=post_params,
                                                  encode_multipart=False,
                                                  headers=headers)
                if headers['Content-Type'] == 'multipart/form-data':
                    # must del headers['Content-Type'], or the correct Content-Type
                    # which generated by urllib3 will be overwritten.
                    del headers['Content-Type']
                    r = self.pool_manager.request(method, url,
                                                  fields=post_params,
                                                  encode_multipart=True,
                                                  headers=headers)
            # For `GET`, `HEAD`, `DELETE`
            else:
                r = self.pool_manager.request(method, url,
                                              fields=query_params,
                                              headers=headers)
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)

        r = RESTResponse(r)

        # log response body
        logger.debug("response body: %s" % r.data)

        if r.status not in range(200, 206):
            raise ApiException(http_resp=r)

        return r

    def GET(self, url, headers=None, query_params=None):
        return self.request("GET", url,
                            headers=headers,
                            query_params=query_params)

    def HEAD(self, url, headers=None, query_params=None):
        return self.request("HEAD", url,
                            headers=headers,
                            query_params=query_params)

    def OPTIONS(self, url, headers=None, query_params=None, post_params=None, body=None):
        return self.request("OPTIONS", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            body=body)

    def DELETE(self, url, headers=None, query_params=None):
        return self.request("DELETE", url,
                            headers=headers,
                            query_params=query_params)

    def POST(self, url, headers=None, query_params=None, post_params=None, body=None):
        return self.request("POST", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            body=body)

    def PUT(self, url, headers=None, query_params=None, post_params=None, body=None):
        return self.request("PUT", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            body=body)

    def PATCH(self, url, headers=None, query_params=None, post_params=None, body=None):
        return self.request("PATCH", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            body=body)


class ApiException(Exception):

    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.status = http_resp.status
            self.reason = http_resp.reason
            self.body = http_resp.data
            self.headers = http_resp.getheaders()
        else:
            self.status = status
            self.reason = reason
            self.body = None
            self.headers = None

    def __str__(self):
        """
        Custom error messages for exception
        """
        error_message = "({0})\n"\
                        "Reason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message



# coding: utf-8

"""
DocApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class DocApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def create_async_doc(self, doc, **kwargs):
        """

        Creates a document asynchronously. You must use a callback url or the the returned status id and the status api to find out when it completes. Then use the download api to get the document.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_async_doc(doc, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Doc doc: The document to be created. (required)
        :return: AsyncDoc
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['doc']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_async_doc" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'doc' is set
        if ('doc' not in params) or (params['doc'] is None):
            raise ValueError("Missing the required parameter `doc` when calling `create_async_doc`")

        resource_path = '/async_docs'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'doc' in params:
            body_params = params['doc']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'application/xml', 'application/pdf', 'application/vnd.ms-excel', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['basicAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='AsyncDoc',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def create_doc(self, doc, **kwargs):
        """

        Creates a document synchronously.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_doc(doc, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Doc doc: The document to be created. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['doc']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_doc" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'doc' is set
        if ('doc' not in params) or (params['doc'] is None):
            raise ValueError("Missing the required parameter `doc` when calling `create_doc`")

        resource_path = '/docs'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'doc' in params:
            body_params = params['doc']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'application/xml', 'application/pdf', 'application/vnd.ms-excel', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['basicAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='str',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_async_doc(self, id, **kwargs):
        """

        Downloads a document.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_async_doc(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The download_id returned from status request or a callback. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_async_doc" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_async_doc`")

        resource_path = '/download/{id}'.replace('{format}', 'json')
        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'application/xml', 'application/pdf', 'application/vnd.ms-excel', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['basicAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='str',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_async_doc_status(self, id, **kwargs):
        """

        Check on the status of an asynchronously created document.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_async_doc_status(id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str id: The status_id returned when creating an asynchronous document. (required)
        :return: AsyncDocStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_async_doc_status" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_async_doc_status`")

        resource_path = '/status/{id}'.replace('{format}', 'json')
        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'application/xml', 'application/pdf', 'application/vnd.ms-excel', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['basicAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='AsyncDocStatus',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

import sys
from setuptools import setup, find_packages

NAME = "docraptor"
VERSION = "0.3.0"



# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.10", "six >= 1.9", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="A wrapper for the DocRaptor HTML to PDF/XLS service.",
    author="Elijah Miller",
    author_email="elijah.miller@gmail.com",
    maintainer="DocRaptor Support",
    maintainer_email="support@docraptor.com",
    url="https://github.com/docraptor/docraptor-python",
    keywords=["DocRaptor", "API", "PDF", "XLS", "XLSX", "HTML"],
    classifiers=[ # see https://pypi.python.org/pypi?%3Aaction=list_classifiers
        "Development Status :: 4 - Beta",

        "Environment :: Web Environment",

        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",

        "License :: OSI Approved :: Apache Software License",

        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX",
        "Operating System :: Unix",

        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Multimedia :: Graphics :: Presentation",
        "Topic :: Office/Business",
        "Topic :: Office/Business :: Financial :: Spreadsheet",

        "Topic :: Printing",
        "Topic :: Text Processing :: Markup :: HTML",
    ],
    license="Apache V2.0 License",
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    A native client library for the DocRaptor HTML to PDF/XLS service.
    """
)
